{ TAMTipDialog component version 2.0, copyright  A. Meeder, 1996-1997

  This is a Tipdialog-component with several properties to customize its behaviour.

  Properties:
  * About: Readonly property that displays a Copyright-message
  * BorderStyle: borderstyle option so you can choose the TipDialogs border bsDialog etc.
  * ButtonCloseCaption: caption of the 'Close'-button
  * ButtonNextCaption: caption of the 'Next'-button
  * Color: this is the color of the panel behind the tip-text
  * OnAtStart: when false the execute method don't display the dialog and returns false
  * OnAtStartCaption: caption of the question 'Show tips next time?'
  * QuestionCaption: caption of the Questionlabel 'Did you know this?'
  * TipDialogCaption: caption of the Dialog, by default 'Tips ...'
  * TipDialogHeader: caption of the 'Welcome-message', by default 'Welcome at ...'
  * Tips: stringlist which contains the tips, one line for every tip

  Events:
  * OnExecute: just before the Tip-dialog appears this event occurs
  * OnExecuted: just after the Tip-dialog is released this event occurs, you can use this event
               to save the 'StartNextTime' property in a INI-file or in the Registry

  You can also test the dialog at runtime by right-clicking the component and choose
  'Test AM Tip Dialog'. When there are no tips assigned to this component this submenu
  isn't available

  Have a question, suggestion? Mail me at: ameeder@dds.nl
}
unit AMTipDlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, DsgnIntf;

type
  TOnExecuted = procedure (Sender: TObject; StartNextTime: boolean) of object;

  TAboutTipDlgProperty = class(TPropertyEditor)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
  end;

  TTipDialogEditor = class(TDefaultEditor)
  public
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: integer; override;
    procedure ExecuteVerb(Index: integer); override;
  end;

  TAMTipDialog = class(TComponent)
  private
    FAbout: TAboutTipDlgProperty;
    FBorderStyle: TFormBorderStyle;
    FCaption: TCaption;
    FClose: TCaption;
    FColor: TColor;
    FHeader: TCaption;
    FNext: TCaption;
    FOnOff: boolean;
    FOnOffCaption: TCaption;
    FQuestion: TCaption;
    FTips: TStringList;

    FOnExecute: TNotifyEvent;
    FOnExecuted: TOnExecuted;

    procedure SetTips(value: TStringList);
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function Execute: boolean;
  published
    property About: TAboutTipDlgProperty read FAbout write FAbout;
    property BorderStyle: TFormBorderStyle read FBorderStyle write FBorderStyle default bsDialog;
    property ButtonCloseCaption: TCaption read FClose write FClose;
    property ButtonNextCaption: TCaption read FNext write FNext;
    property Color: TColor read FColor write FColor default clYellow;
    property OnAtStart: boolean read FOnOff write FOnOff default true;
    property OnAtStartCaption: TCaption read FOnOffCaption write FOnOffCaption;
    property QuestionCaption: TCaption read FQuestion write FQuestion;
    property TipDialogCaption: TCaption read FCaption write FCaption;
    property TipDialogHeader: TCaption read FHeader write FHeader;
    property Tips: TStringList read FTips write SetTips;
    property OnExecute: TNotifyEvent read FOnExecute write FOnExecute;
    property OnExecuted: TOnExecuted read FOnExecuted write FOnExecuted;
  end;

  TTipForm = class(TForm)
    lblHeader: TLabel;
    pnlTip: TPanel;
    btnNext: TButton;
    btnClose: TButton;
    Bevel1: TBevel;
    chkOnOff: TCheckBox;
    lblQuestion: TLabel;
    lblTip: TLabel;
    Image1: TImage;
    procedure btnNextClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private

  public
    Tips: TStringList;
  end;

procedure Register;

implementation

{$R *.DFM}

var
  NumTip: Word;
  TipForm: TTipForm;

// Beginning of code for TTipDialogEditor
function TTipDialogEditor.GetVerbCount: integer;
begin
  if (Component as TAMTipDialog).Tips.Count = 0 then
    Result := 0
  else
    Result := 1;
end;

function TTipDialogEditor.GetVerb(Index: integer): string;
begin
  Result := '&Test AM Tip Dialog';
end;

procedure TTipDialogEditor.ExecuteVerb;
begin
  (Component as TAMTipDialog).Execute;
end;

// Beginning of code for AboutTipDlgProperty-editor
procedure TAboutTipDlgProperty.Edit;
const
  Hrt = #13#10;
begin
  Application.MessageBox('This is a freeware component.'+Hrt+
                         'Copyright  1996-1997 by AM Software'+Hrt+
                         'programmed by Alexander Meeder (ameeder@dds.nl)'+Hrt+
	                 'AMTipDialog version 2.0','AMTipDialog 2.0', MB_OK+MB_ICONINFORMATION);
end;

function TAboutTipDlgProperty.GetAttributes: TPropertyAttributes;
begin
  Result := inherited GetAttributes + [paDialog, paReadOnly];
end;

function TAboutTipDlgProperty.GetValue: string;
begin
  Result := '(About)';
end;

// Beginning of the TipDialog-code
constructor TAMTipDialog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FBorderStyle := bsDialog;
  FCaption := 'Tips ...';
  FClose := '&Close';
  FColor := clYellow;
  FHeader := 'Welcome at ...';
  FNext := '&Next';
  FOnOff := true;
  FOnOffCaption := 'Show tips next time?';
  FQuestion := 'Did you know this?';
  FTips := TStringList.Create;
end;

destructor TAMTipDialog.Destroy;
begin
  FTips.Free;
  inherited Destroy;
end;

procedure TAMTipDialog.SetTips(value: TStringList);
begin
  FTips.Assign(value);
end;

function TAMTipDialog.Execute: boolean;
begin
  Result := False;
  if (Tips.Count <> 0) and (OnAtStart) then
  begin
    TipForm := TTipForm.Create(Application);
    try
      TipForm.BorderStyle := Self.BorderStyle;
      TipForm.btnNext.Caption := Self.ButtonNextCaption;
      TipForm.btnClose.Caption := Self.ButtonCloseCaption;
      TipForm.Caption := Self.TipDialogCaption;
      TipForm.pnlTip.Color := Self.Color;
      TipForm.chkOnOff.Checked := Self.OnAtStart;
      TipForm.chkOnOff.Caption := Self.OnAtStartCaption;
      TipForm.lblHeader.Caption := Self.TipDialogHeader;
      TipForm.lblQuestion.Caption := Self.QuestionCaption;
      TipForm.Tips.Assign(Tips);

      if Assigned(FOnExecute) then FOnExecute(Self);
      result := TipForm.ShowModal = mrOk;
      if Assigned(FOnExecuted) then FOnExecuted(Self, (TipForm.chkOnOff.Checked));
    finally
      TipForm.Free;
    end;
  end;
end;

// Beginning the internal TipForm-methods
procedure TTipForm.FormCreate(Sender: TObject);
begin
  Tips := TStringList.Create;
end;

procedure TTipForm.FormDestroy(Sender: TObject);
begin
  Tips.Free;
end;

procedure TTipForm.FormShow(Sender: TObject);
begin
  if Tips.Count = 1 then btnNext.Enabled := false;
  Randomize;
  NumTip := Random(Tips.Count);
  lblTip.Caption := Tips.Strings[NumTip];
end;

procedure TTipForm.btnNextClick(Sender: TObject);
begin
  NumTip := Random(Tips.Count);
  lblTip.Caption := Tips.Strings[NumTip];
end;

// Registering the components
procedure Register;
begin
  RegisterComponents('Dialogs', [TAMTipDialog]);
  RegisterPropertyEditor(TypeInfo(TAboutTipDlgProperty), TAMTipDialog, 'ABOUT', TAboutTipDlgProperty);
  RegisterComponentEditor(TAMTipDialog, TTipDialogEditor);
end;

end.
